summaryrefslogtreecommitdiffstats
path: root/siplib/voidptr.c
diff options
context:
space:
mode:
Diffstat (limited to 'siplib/voidptr.c')
-rw-r--r--siplib/voidptr.c28
1 files changed, 14 insertions, 14 deletions
diff --git a/siplib/voidptr.c b/siplib/voidptr.c
index fc26046..65d4fe9 100644
--- a/siplib/voidptr.c
+++ b/siplib/voidptr.c
@@ -1,18 +1,18 @@
/*
- * SIP library code.
+ * SIP-TQt library code.
*
* Copyright (c) 2010 Riverbank Computing Limited <info@riverbankcomputing.com>
*
* This file is part of SIP.
*
- * This copy of SIP is licensed for use under the terms of the SIP License
+ * This copy of SIP-TQt is licensed for use under the terms of the SIP License
* Agreement. See the file LICENSE for more details.
*
* This copy of SIP may also used under the terms of the GNU General Public
* License v2 or v3 as published by the Free Software Foundation which can be
* found in the files LICENSE-GPL2 and LICENSE-GPL3 included in this package.
*
* SIP is supplied WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
*/
@@ -21,7 +21,7 @@
#include <stddef.h>
-#include "sip.h"
+#include "sip-tqt.h"
#include "sipint.h"
@@ -134,7 +134,7 @@ static SIP_SSIZE_T sipVoidPtr_getwritebuffer(PyObject *self, SIP_SSIZE_T seg,
if (((sipVoidPtrObject *)self)->rw)
return sipVoidPtr_getbuffer(self, seg, ptr);
- PyErr_SetString(PyExc_TypeError, "the sip.voidptr is not writeable");
+ PyErr_SetString(PyExc_TypeError, "the sip_tqt.voidptr is not writeable");
return -1;
}
#endif
@@ -230,7 +230,7 @@ static PyObject *sipVoidPtr_asstring(sipVoidPtrObject *v, PyObject *args,
if (size < 0)
{
PyErr_SetString(PyExc_ValueError,
- "a size must be given or the sip.voidptr must have a size");
+ "a size must be given or the sip_tqt.voidptr must have a size");
return NULL;
}
@@ -395,7 +395,7 @@ static PyBufferProcs sipVoidPtr_BufferProcs = {
/* The type data structure. */
PyTypeObject sipVoidPtr_Type = {
PyVarObject_HEAD_INIT(NULL, 0)
- "sip.voidptr", /* tp_name */
+ "sip_tqt.voidptr", /* tp_name */
sizeof (sipVoidPtrObject), /* tp_basicsize */
0, /* tp_itemsize */
0, /* tp_dealloc */
@@ -442,7 +442,7 @@ void *sip_api_convert_to_void_ptr(PyObject *obj)
{
if (obj == NULL)
{
- PyErr_SetString(PyExc_TypeError, "sip.voidptr is NULL");
+ PyErr_SetString(PyExc_TypeError, "sip_tqt.voidptr is NULL");
return NULL;
}
@@ -469,7 +469,7 @@ void *sip_api_convert_to_void_ptr(PyObject *obj)
/*
* Convert a C/C++ void pointer to a sip.voidptr object.
*/
PyObject *sip_api_convert_from_void_ptr(void *val)
{
@@ -478,7 +478,7 @@ PyObject *sip_api_convert_from_void_ptr(void *val)
/*
* Convert a C/C++ void pointer to a sip.voidptr object.
*/
PyObject *sip_api_convert_from_const_void_ptr(const void *val)
{
@@ -487,7 +487,7 @@ PyObject *sip_api_convert_from_const_void_ptr(const void *val)
/*
* Convert a sized C/C++ void pointer to a sip.voidptr object.
*/
PyObject *sip_api_convert_from_void_ptr_and_size(void *val, SIP_SSIZE_T size)
{
@@ -496,7 +496,7 @@ PyObject *sip_api_convert_from_void_ptr_and_size(void *val, SIP_SSIZE_T size)
/*
* Convert a sized C/C++ const void pointer to a sip.voidptr object.
*/
PyObject *sip_api_convert_from_const_void_ptr_and_size(const void *val,
SIP_SSIZE_T size)
@@ -1,18 +1,18 @@
* Copyright (c) 2010 Riverbank Computing Limited <info@riverbankcomputing.com>
*
- * This file is part of SIP.
+ * This file is part of SIP-TQt.
*
@@ -1,18 +1,18 @@
* Agreement. See the file LICENSE for more details.
*
- * This copy of SIP may also used under the terms of the GNU General Public
+ * This copy of SIP-TQt may also used under the terms of the GNU General Public
* License v2 or v3 as published by the Free Software Foundation which can be
* found in the files LICENSE-GPL2 and LICENSE-GPL3 included in this package.
@@ -1,18 +1,18 @@
* found in the files LICENSE-GPL2 and LICENSE-GPL3 included in this package.
*
- * SIP is supplied WITHOUT ANY WARRANTY; without even the implied warranty of
+ * SIP-TQt is supplied WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
*/
@@ -469,7 +469,7 @@ void *sip_api_convert_to_void_ptr(PyObject *obj)
/*
- * Convert a C/C++ void pointer to a sip.voidptr object.
+ * Convert a C/C++ void pointer to a sip_tqt.voidptr object.
*/
PyObject *sip_api_convert_from_void_ptr(void *val)
@@ -478,7 +478,7 @@ PyObject *sip_api_convert_from_void_ptr(void *val)
/*
- * Convert a C/C++ void pointer to a sip.voidptr object.
+ * Convert a C/C++ void pointer to a sip_tqt.voidptr object.
*/
PyObject *sip_api_convert_from_const_void_ptr(const void *val)
@@ -487,7 +487,7 @@ PyObject *sip_api_convert_from_const_void_ptr(const void *val)
/*
- * Convert a sized C/C++ void pointer to a sip.voidptr object.
+ * Convert a sized C/C++ void pointer to a sip_tqt.voidptr object.
*/
PyObject *sip_api_convert_from_void_ptr_and_size(void *val, SIP_SSIZE_T size)
@@ -496,7 +496,7 @@ PyObject *sip_api_convert_from_void_ptr_and_size(void *val, SIP_SSIZE_T size)
/*
- * Convert a sized C/C++ const void pointer to a sip.voidptr object.
+ * Convert a sized C/C++ const void pointer to a sip_tqt.voidptr object.
*/
PyObject *sip_api_convert_from_const_void_ptr_and_size(const void *val,